import { IgrAxis } from "./igr-axis";
import { DataToolTipLayerGroupingMode_$type } from "igniteui-react-core";
import { DataTooltipGroupedPositionX_$type } from "igniteui-react-core";
import { DataTooltipGroupedPositionY_$type } from "igniteui-react-core";
import { DataAbbreviationMode_$type } from "igniteui-react-core";
import { DataLegendValueMode_$type } from "igniteui-react-core";
import { DataLegendHeaderDateMode_$type } from "igniteui-react-core";
import { DataLegendHeaderTimeMode_$type } from "igniteui-react-core";
import { DataLegendSummaryType_$type } from "igniteui-react-core";
import { LegendItemBadgeShape_$type } from "igniteui-react-core";
import { DataLegendLayoutMode_$type } from "igniteui-react-core";
import { DataLegendUnitsMode_$type } from "igniteui-react-core";
import { DataLegendLabelMode_$type } from "igniteui-react-core";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { DataToolTipLayer } from "./DataToolTipLayer";
import { ensureBool, ensureEnum, brushToString, stringToBrush, arrayFindByName } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
/**
 * Represents an annotation layer that displays grouped tooltips with summaries for series.
*/
export class IgrDataToolTipLayer extends IgrAnnotationLayer {
    createImplementation() {
        return new DataToolTipLayer();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the series is an annotation layer displayed only when hovering over the chart.
    */
    get isAnnotationHoverLayer() {
        return this.i.eq;
    }
    /**
     * Gets whether the default tooltip behaviors for the chart are disabled if this layer is present.
    */
    get isDefaultTooltipBehaviorDisabled() {
        return this.i.e1;
    }
    /**
     * Gets or sets the Axis to target this annotation to. If null, this annotation layer will not render content.
    */
    get targetAxis() {
        const r = this.i.z1;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = IgrAxis._createFromInternal(r);
            if (e) {
                e._implementation = r;
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set targetAxis(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.z1 = null : this.i.z1 = v.i;
    }
    /**
     * Gets or sets whether to use value interpolation when drawing the tooltips.
    */
    get useInterpolation() {
        return this.i.abj;
    }
    set useInterpolation(v) {
        this.i.abj = ensureBool(v);
    }
    /**
     * Gets or sets the grouping mode to apply to use for the tooltip layer.
    */
    get groupingMode() {
        return this.i.aak;
    }
    set groupingMode(v) {
        this.i.aak = ensureEnum(DataToolTipLayerGroupingMode_$type, v);
    }
    /**
     * Gets the actual resolved tooltip layer grouping mode.
    */
    get actualGroupingMode() {
        return this.i.aaj;
    }
    set actualGroupingMode(v) {
        this.i.aaj = ensureEnum(DataToolTipLayerGroupingMode_$type, v);
    }
    /**
     * Gets or sets the offset of the tooltip layer on the X axis.
    */
    get positionOffsetX() {
        return this.i.abs;
    }
    set positionOffsetX(v) {
        this.i.abs = +v;
    }
    /**
     * Gets or sets the offset of the tooltip layer on the Y axis.
    */
    get positionOffsetY() {
        return this.i.abt;
    }
    set positionOffsetY(v) {
        this.i.abt = +v;
    }
    /**
     * Gets or sets the default offset of the tooltip layer on the X axis.
    */
    get defaultPositionOffsetX() {
        return this.i.abq;
    }
    set defaultPositionOffsetX(v) {
        this.i.abq = +v;
    }
    /**
     * Gets or sets the default offset of the tooltip layer on the Y axis.
    */
    get defaultPositionOffsetY() {
        return this.i.abr;
    }
    set defaultPositionOffsetY(v) {
        this.i.abr = +v;
    }
    /**
     * Gets or sets the tooltip position mode on the X axis for grouped series.
    */
    get groupedPositionModeX() {
        return this.i.aac;
    }
    set groupedPositionModeX(v) {
        this.i.aac = ensureEnum(DataTooltipGroupedPositionX_$type, v);
    }
    /**
     * Gets the actual resolved tooltip position mode on the X axis for grouped series.
    */
    get actualGroupedPositionModeX() {
        return this.i.aab;
    }
    set actualGroupedPositionModeX(v) {
        this.i.aab = ensureEnum(DataTooltipGroupedPositionX_$type, v);
    }
    /**
     * Gets or sets the tooltip position mode on the Y axis for grouped series.
    */
    get groupedPositionModeY() {
        return this.i.aag;
    }
    set groupedPositionModeY(v) {
        this.i.aag = ensureEnum(DataTooltipGroupedPositionY_$type, v);
    }
    /**
     * Gets the actual resolved tooltip position mode on the Y axis for grouped series.
    */
    get actualGroupedPositionModeY() {
        return this.i.aaf;
    }
    set actualGroupedPositionModeY(v) {
        this.i.aaf = ensureEnum(DataTooltipGroupedPositionY_$type, v);
    }
    /**
     * Gets or sets whether the data legend should update when the series data is mutated.
    */
    get shouldUpdateWhenSeriesDataChanges() {
        return this.i.abi;
    }
    set shouldUpdateWhenSeriesDataChanges(v) {
        this.i.abi = ensureBool(v);
    }
    /**
     * Gets or sets indexes, titles, or names of series to include in displaying in the data legend, e.g. "0, 1" or "Series1 Title, Series2 Title"
     * The ExcludedSeries property takes precedence over values of IncludedSeries property
    */
    get includedSeries() {
        return this.i.zy;
    }
    set includedSeries(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.zy = v;
    }
    /**
     * Gets or sets indexes, titles, or names of series to exclude from displaying in the data legend, e.g. "0, 1" or "Series1 Title, Series2 Title"
     * The ExcludedSeries property takes precedence over values of IncludedSeries property
    */
    get excludedSeries() {
        return this.i.zt;
    }
    set excludedSeries(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.zt = v;
    }
    /**
     * Gets or sets names of data columns or their labels to include in displaying in the data tooltip, e.g. "High, Low" or "H, L"
     * The ExcludedColumns property takes precedence over values of IncludedColumns property
    */
    get includedColumns() {
        return this.i.zx;
    }
    set includedColumns(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.zx = v;
    }
    /**
     * Gets or sets names of data columns or their labels to exclude from displaying in the data tooltip, e.g. "High, Low" or "H, L"
     * The ExcludedColumns property takes precedence over values of IncludedColumns property
    */
    get excludedColumns() {
        return this.i.zs;
    }
    set excludedColumns(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.zs = v;
    }
    /**
     * Gets or sets mode for abbreviating large numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatAbbreviation() {
        return this.i.z2;
    }
    set valueFormatAbbreviation(v) {
        this.i.z2 = ensureEnum(DataAbbreviationMode_$type, v);
    }
    /**
     * Gets or sets maximum digits for formatting numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatMaxFractions() {
        return this.i.acs;
    }
    set valueFormatMaxFractions(v) {
        this.i.acs = +v;
    }
    /**
     * Gets or sets minimum digits for formatting numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatMinFractions() {
        return this.i.act;
    }
    set valueFormatMinFractions(v) {
        this.i.act = +v;
    }
    /**
     * Gets or sets the mode for displaying values in the data legend, e.g. Currency ($500.25), Decimal (500.25), Integer (500)
    */
    get valueFormatMode() {
        return this.i.z9;
    }
    set valueFormatMode(v) {
        this.i.z9 = ensureEnum(DataLegendValueMode_$type, v);
    }
    /**
     * Gets or sets globalization culture when displaying values as currencies, e.g. use "en-GB" to display British pound symbol when the ValueFormatMode property is set to 'Currency' mode
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatCulture() {
        return this.i.aet;
    }
    set valueFormatCulture(v) {
        this.i.aet = v;
    }
    /**
     * Gets or sets whether or not use grouping separator, e.g, 15,000 for 15000
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get valueFormatUseGrouping() {
        return this.i.abk;
    }
    set valueFormatUseGrouping(v) {
        this.i.abk = ensureBool(v);
    }
    /**
     * Gets or sets the format string for values displayed in the data legend.
    */
    get valueFormatString() {
        return this.i.aez;
    }
    set valueFormatString(v) {
        this.i.aez = v;
    }
    /**
     * Gets or sets the format specifiers to use with the ValueFormatString string.
    */
    get valueFormatSpecifiers() {
        return this.i.zz;
    }
    set valueFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.zz = v;
    }
    get valueRowMarginBottom() {
        return this.i.ahy ? this.i.ahy.bottom : NaN;
    }
    set valueRowMarginBottom(v) {
        this.ensureValueRowMargin();
        this.i.ahy.bottom = +v;
        this.i.ahy = this.i.ahy;
    }
    get valueRowMarginLeft() {
        return this.i.ahy ? this.i.ahy.left : NaN;
    }
    set valueRowMarginLeft(v) {
        this.ensureValueRowMargin();
        this.i.ahy.left = +v;
        this.i.ahy = this.i.ahy;
    }
    get valueRowMarginRight() {
        return this.i.ahy ? this.i.ahy.right : NaN;
    }
    set valueRowMarginRight(v) {
        this.ensureValueRowMargin();
        this.i.ahy.right = +v;
        this.i.ahy = this.i.ahy;
    }
    get valueRowMarginTop() {
        return this.i.ahy ? this.i.ahy.top : NaN;
    }
    set valueRowMarginTop(v) {
        this.ensureValueRowMargin();
        this.i.ahy.top = +v;
        this.i.ahy = this.i.ahy;
    }
    ensureValueRowMargin() {
        if (this.i.ahy) {
            return;
        }
        this.i.ahy = new Thickness(2);
    }
    /**
     * Gets or sets whether to show series rows.
    */
    get valueRowVisible() {
        return this.i.abl;
    }
    set valueRowVisible(v) {
        this.i.abl = ensureBool(v);
    }
    /**
     * Gets or sets text displayed when data column is missing a value, e.g. "no data"
    */
    get valueTextWhenMissingData() {
        return this.i.ae8;
    }
    set valueTextWhenMissingData(v) {
        this.i.ae8 = v;
    }
    /**
     * Gets or sets whether to use series colors when displaying values in the legend
    */
    get valueTextUseSeriesColors() {
        return this.i.abm;
    }
    set valueTextUseSeriesColors(v) {
        this.i.abm = ensureBool(v);
    }
    get valueTextMarginBottom() {
        return this.i.ahz ? this.i.ahz.bottom : NaN;
    }
    set valueTextMarginBottom(v) {
        this.ensureValueTextMargin();
        this.i.ahz.bottom = +v;
        this.i.ahz = this.i.ahz;
    }
    get valueTextMarginLeft() {
        return this.i.ahz ? this.i.ahz.left : NaN;
    }
    set valueTextMarginLeft(v) {
        this.ensureValueTextMargin();
        this.i.ahz.left = +v;
        this.i.ahz = this.i.ahz;
    }
    get valueTextMarginRight() {
        return this.i.ahz ? this.i.ahz.right : NaN;
    }
    set valueTextMarginRight(v) {
        this.ensureValueTextMargin();
        this.i.ahz.right = +v;
        this.i.ahz = this.i.ahz;
    }
    get valueTextMarginTop() {
        return this.i.ahz ? this.i.ahz.top : NaN;
    }
    set valueTextMarginTop(v) {
        this.ensureValueTextMargin();
        this.i.ahz.top = +v;
        this.i.ahz = this.i.ahz;
    }
    ensureValueTextMargin() {
        if (this.i.ahz) {
            return;
        }
        this.i.ahz = new Thickness(2);
    }
    /**
     * Gets or sets the units text color.
    */
    get valueTextColor() {
        return brushToString(this.i.ahh);
    }
    set valueTextColor(v) {
        this.i.ahh = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get valueTextStyle() {
        if (this.i.aa8 == null) {
            return null;
        }
        return this.i.aa8.fontString;
    }
    set valueTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.aa8 = fi;
    }
    /**
     * Gets or sets the format string for header text displayed in the data legend.
    */
    get headerFormatString() {
        return this.i.adg;
    }
    set headerFormatString(v) {
        this.i.adg = v;
    }
    /**
     * Gets or sets the format specifiers to use with the HeaderFormatString string.
    */
    get headerFormatSpecifiers() {
        return this.i.zw;
    }
    set headerFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.zw = v;
    }
    /**
     * Gets or sets globalization culture when displaying header as date time
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatCulture() {
        return this.i.adc;
    }
    set headerFormatCulture(v) {
        this.i.adc = v;
    }
    /**
     * Gets or sets date format for the header
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatDate() {
        return this.i.z3;
    }
    set headerFormatDate(v) {
        this.i.z3 = ensureEnum(DataLegendHeaderDateMode_$type, v);
    }
    /**
     * Gets or sets time format for the header
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get headerFormatTime() {
        return this.i.z4;
    }
    set headerFormatTime(v) {
        this.i.z4 = ensureEnum(DataLegendHeaderTimeMode_$type, v);
    }
    /**
     * Gets or sets the HeaderText for the data legend.
    */
    get headerText() {
        return this.i.adl;
    }
    set headerText(v) {
        this.i.adl = v;
    }
    /**
     * Gets or sets the header text color.
    */
    get headerTextColor() {
        return brushToString(this.i.ag9);
    }
    set headerTextColor(v) {
        this.i.ag9 = stringToBrush(v);
    }
    get headerTextMarginBottom() {
        return this.i.ahs ? this.i.ahs.bottom : NaN;
    }
    set headerTextMarginBottom(v) {
        this.ensureHeaderTextMargin();
        this.i.ahs.bottom = +v;
        this.i.ahs = this.i.ahs;
    }
    get headerTextMarginLeft() {
        return this.i.ahs ? this.i.ahs.left : NaN;
    }
    set headerTextMarginLeft(v) {
        this.ensureHeaderTextMargin();
        this.i.ahs.left = +v;
        this.i.ahs = this.i.ahs;
    }
    get headerTextMarginRight() {
        return this.i.ahs ? this.i.ahs.right : NaN;
    }
    set headerTextMarginRight(v) {
        this.ensureHeaderTextMargin();
        this.i.ahs.right = +v;
        this.i.ahs = this.i.ahs;
    }
    get headerTextMarginTop() {
        return this.i.ahs ? this.i.ahs.top : NaN;
    }
    set headerTextMarginTop(v) {
        this.ensureHeaderTextMargin();
        this.i.ahs.top = +v;
        this.i.ahs = this.i.ahs;
    }
    ensureHeaderTextMargin() {
        if (this.i.ahs) {
            return;
        }
        this.i.ahs = new Thickness(2);
    }
    get headerRowMarginBottom() {
        return this.i.ahr ? this.i.ahr.bottom : NaN;
    }
    set headerRowMarginBottom(v) {
        this.ensureHeaderRowMargin();
        this.i.ahr.bottom = +v;
        this.i.ahr = this.i.ahr;
    }
    get headerRowMarginLeft() {
        return this.i.ahr ? this.i.ahr.left : NaN;
    }
    set headerRowMarginLeft(v) {
        this.ensureHeaderRowMargin();
        this.i.ahr.left = +v;
        this.i.ahr = this.i.ahr;
    }
    get headerRowMarginRight() {
        return this.i.ahr ? this.i.ahr.right : NaN;
    }
    set headerRowMarginRight(v) {
        this.ensureHeaderRowMargin();
        this.i.ahr.right = +v;
        this.i.ahr = this.i.ahr;
    }
    get headerRowMarginTop() {
        return this.i.ahr ? this.i.ahr.top : NaN;
    }
    set headerRowMarginTop(v) {
        this.ensureHeaderRowMargin();
        this.i.ahr.top = +v;
        this.i.ahr = this.i.ahr;
    }
    ensureHeaderRowMargin() {
        if (this.i.ahr) {
            return;
        }
        this.i.ahr = new Thickness(2);
    }
    /**
     * Gets or sets whether to show Header row.
    */
    get headerRowVisible() {
        return this.i.abb;
    }
    set headerRowVisible(v) {
        this.i.abb = ensureBool(v);
    }
    /**
     * Gets or Sets the style to use for the header text.
    */
    get headerTextStyle() {
        if (this.i.aa0 == null) {
            return null;
        }
        return this.i.aa0.fontString;
    }
    set headerTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.aa0 = fi;
    }
    /**
     * Gets or sets whether to show Header row.
    */
    get groupRowVisible() {
        return this.i.aba;
    }
    set groupRowVisible(v) {
        this.i.aba = ensureBool(v);
    }
    /**
     * Gets or sets the Group text color.
    */
    get groupTextColor() {
        return brushToString(this.i.ag8);
    }
    set groupTextColor(v) {
        this.i.ag8 = stringToBrush(v);
    }
    get groupTextMarginBottom() {
        return this.i.ahq ? this.i.ahq.bottom : NaN;
    }
    set groupTextMarginBottom(v) {
        this.ensureGroupTextMargin();
        this.i.ahq.bottom = +v;
        this.i.ahq = this.i.ahq;
    }
    get groupTextMarginLeft() {
        return this.i.ahq ? this.i.ahq.left : NaN;
    }
    set groupTextMarginLeft(v) {
        this.ensureGroupTextMargin();
        this.i.ahq.left = +v;
        this.i.ahq = this.i.ahq;
    }
    get groupTextMarginRight() {
        return this.i.ahq ? this.i.ahq.right : NaN;
    }
    set groupTextMarginRight(v) {
        this.ensureGroupTextMargin();
        this.i.ahq.right = +v;
        this.i.ahq = this.i.ahq;
    }
    get groupTextMarginTop() {
        return this.i.ahq ? this.i.ahq.top : NaN;
    }
    set groupTextMarginTop(v) {
        this.ensureGroupTextMargin();
        this.i.ahq.top = +v;
        this.i.ahq = this.i.ahq;
    }
    ensureGroupTextMargin() {
        if (this.i.ahq) {
            return;
        }
        this.i.ahq = new Thickness(2);
    }
    get groupRowMarginBottom() {
        return this.i.ahp ? this.i.ahp.bottom : NaN;
    }
    set groupRowMarginBottom(v) {
        this.ensureGroupRowMargin();
        this.i.ahp.bottom = +v;
        this.i.ahp = this.i.ahp;
    }
    get groupRowMarginLeft() {
        return this.i.ahp ? this.i.ahp.left : NaN;
    }
    set groupRowMarginLeft(v) {
        this.ensureGroupRowMargin();
        this.i.ahp.left = +v;
        this.i.ahp = this.i.ahp;
    }
    get groupRowMarginRight() {
        return this.i.ahp ? this.i.ahp.right : NaN;
    }
    set groupRowMarginRight(v) {
        this.ensureGroupRowMargin();
        this.i.ahp.right = +v;
        this.i.ahp = this.i.ahp;
    }
    get groupRowMarginTop() {
        return this.i.ahp ? this.i.ahp.top : NaN;
    }
    set groupRowMarginTop(v) {
        this.ensureGroupRowMargin();
        this.i.ahp.top = +v;
        this.i.ahp = this.i.ahp;
    }
    ensureGroupRowMargin() {
        if (this.i.ahp) {
            return;
        }
        this.i.ahp = new Thickness(2);
    }
    /**
     * Gets or Sets the style to use for the Group text.
    */
    get groupTextStyle() {
        if (this.i.aaz == null) {
            return null;
        }
        return this.i.aaz.fontString;
    }
    set groupTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.aaz = fi;
    }
    /**
     * Gets or sets the summary text color.
    */
    get summaryTitleTextColor() {
        return brushToString(this.i.ahc);
    }
    set summaryTitleTextColor(v) {
        this.i.ahc = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the summary text.
    */
    get summaryTitleTextStyle() {
        if (this.i.aa3 == null) {
            return null;
        }
        return this.i.aa3.fontString;
    }
    set summaryTitleTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.aa3 = fi;
    }
    /**
     * Gets or sets the SummaryType for the data legend.
    */
    get summaryType() {
        return this.i.z7;
    }
    set summaryType(v) {
        this.i.z7 = ensureEnum(DataLegendSummaryType_$type, v);
    }
    /**
     * Gets or sets the SummaryTitleText for the data legend.
    */
    get summaryTitleText() {
        return this.i.ad5;
    }
    set summaryTitleText(v) {
        this.i.ad5 = v;
    }
    get summaryTitleTextMarginBottom() {
        return this.i.ahv ? this.i.ahv.bottom : NaN;
    }
    set summaryTitleTextMarginBottom(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.ahv.bottom = +v;
        this.i.ahv = this.i.ahv;
    }
    get summaryTitleTextMarginLeft() {
        return this.i.ahv ? this.i.ahv.left : NaN;
    }
    set summaryTitleTextMarginLeft(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.ahv.left = +v;
        this.i.ahv = this.i.ahv;
    }
    get summaryTitleTextMarginRight() {
        return this.i.ahv ? this.i.ahv.right : NaN;
    }
    set summaryTitleTextMarginRight(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.ahv.right = +v;
        this.i.ahv = this.i.ahv;
    }
    get summaryTitleTextMarginTop() {
        return this.i.ahv ? this.i.ahv.top : NaN;
    }
    set summaryTitleTextMarginTop(v) {
        this.ensureSummaryTitleTextMargin();
        this.i.ahv.top = +v;
        this.i.ahv = this.i.ahv;
    }
    ensureSummaryTitleTextMargin() {
        if (this.i.ahv) {
            return;
        }
        this.i.ahv = new Thickness(2);
    }
    get summaryRowMarginBottom() {
        return this.i.ahu ? this.i.ahu.bottom : NaN;
    }
    set summaryRowMarginBottom(v) {
        this.ensureSummaryRowMargin();
        this.i.ahu.bottom = +v;
        this.i.ahu = this.i.ahu;
    }
    get summaryRowMarginLeft() {
        return this.i.ahu ? this.i.ahu.left : NaN;
    }
    set summaryRowMarginLeft(v) {
        this.ensureSummaryRowMargin();
        this.i.ahu.left = +v;
        this.i.ahu = this.i.ahu;
    }
    get summaryRowMarginRight() {
        return this.i.ahu ? this.i.ahu.right : NaN;
    }
    set summaryRowMarginRight(v) {
        this.ensureSummaryRowMargin();
        this.i.ahu.right = +v;
        this.i.ahu = this.i.ahu;
    }
    get summaryRowMarginTop() {
        return this.i.ahu ? this.i.ahu.top : NaN;
    }
    set summaryRowMarginTop(v) {
        this.ensureSummaryRowMargin();
        this.i.ahu.top = +v;
        this.i.ahu = this.i.ahu;
    }
    ensureSummaryRowMargin() {
        if (this.i.ahu) {
            return;
        }
        this.i.ahu = new Thickness(2);
    }
    /**
     * Gets or sets the units text color.
    */
    get summaryValueTextColor() {
        return brushToString(this.i.ahe);
    }
    set summaryValueTextColor(v) {
        this.i.ahe = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryValueTextStyle() {
        if (this.i.aa5 == null) {
            return null;
        }
        return this.i.aa5.fontString;
    }
    set summaryValueTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.aa5 = fi;
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get summaryLabelText() {
        return this.i.ad0;
    }
    set summaryLabelText(v) {
        this.i.ad0 = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get summaryLabelTextColor() {
        return brushToString(this.i.ahb);
    }
    set summaryLabelTextColor(v) {
        this.i.ahb = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryLabelTextStyle() {
        if (this.i.aa2 == null) {
            return null;
        }
        return this.i.aa2.fontString;
    }
    set summaryLabelTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.aa2 = fi;
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get summaryUnitsText() {
        return this.i.aeb;
    }
    set summaryUnitsText(v) {
        this.i.aeb = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get summaryUnitsTextColor() {
        return brushToString(this.i.ahd);
    }
    set summaryUnitsTextColor(v) {
        this.i.ahd = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get summaryUnitsTextStyle() {
        if (this.i.aa4 == null) {
            return null;
        }
        return this.i.aa4.fontString;
    }
    set summaryUnitsTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.aa4 = fi;
    }
    get badgeMarginBottom() {
        return this.i.aho ? this.i.aho.bottom : NaN;
    }
    set badgeMarginBottom(v) {
        this.ensureBadgeMargin();
        this.i.aho.bottom = +v;
        this.i.aho = this.i.aho;
    }
    get badgeMarginLeft() {
        return this.i.aho ? this.i.aho.left : NaN;
    }
    set badgeMarginLeft(v) {
        this.ensureBadgeMargin();
        this.i.aho.left = +v;
        this.i.aho = this.i.aho;
    }
    get badgeMarginRight() {
        return this.i.aho ? this.i.aho.right : NaN;
    }
    set badgeMarginRight(v) {
        this.ensureBadgeMargin();
        this.i.aho.right = +v;
        this.i.aho = this.i.aho;
    }
    get badgeMarginTop() {
        return this.i.aho ? this.i.aho.top : NaN;
    }
    set badgeMarginTop(v) {
        this.ensureBadgeMargin();
        this.i.aho.top = +v;
        this.i.aho = this.i.aho;
    }
    ensureBadgeMargin() {
        if (this.i.aho) {
            return;
        }
        this.i.aho = new Thickness(2);
    }
    /**
     * Gets or sets the BadgeShape for the data legend.
    */
    get badgeShape() {
        return this.i.aao;
    }
    set badgeShape(v) {
        this.i.aao = ensureEnum(LegendItemBadgeShape_$type, v);
    }
    /**
     * Gets or sets the layout of content in the data legend
    */
    get layoutMode() {
        return this.i.z6;
    }
    set layoutMode(v) {
        this.i.z6 = ensureEnum(DataLegendLayoutMode_$type, v);
    }
    /**
     * Gets or sets the UnitsMode for the data legend.
    */
    get unitsDisplayMode() {
        return this.i.z8;
    }
    set unitsDisplayMode(v) {
        this.i.z8 = ensureEnum(DataLegendUnitsMode_$type, v);
    }
    /**
     * Gets or sets the units text for the data legend.
    */
    get unitsText() {
        return this.i.aem;
    }
    set unitsText(v) {
        this.i.aem = v;
    }
    /**
     * Gets or sets the units text color.
    */
    get unitsTextColor() {
        return brushToString(this.i.ahg);
    }
    set unitsTextColor(v) {
        this.i.ahg = stringToBrush(v);
    }
    get unitsTextMarginBottom() {
        return this.i.ahx ? this.i.ahx.bottom : NaN;
    }
    set unitsTextMarginBottom(v) {
        this.ensureUnitsTextMargin();
        this.i.ahx.bottom = +v;
        this.i.ahx = this.i.ahx;
    }
    get unitsTextMarginLeft() {
        return this.i.ahx ? this.i.ahx.left : NaN;
    }
    set unitsTextMarginLeft(v) {
        this.ensureUnitsTextMargin();
        this.i.ahx.left = +v;
        this.i.ahx = this.i.ahx;
    }
    get unitsTextMarginRight() {
        return this.i.ahx ? this.i.ahx.right : NaN;
    }
    set unitsTextMarginRight(v) {
        this.ensureUnitsTextMargin();
        this.i.ahx.right = +v;
        this.i.ahx = this.i.ahx;
    }
    get unitsTextMarginTop() {
        return this.i.ahx ? this.i.ahx.top : NaN;
    }
    set unitsTextMarginTop(v) {
        this.ensureUnitsTextMargin();
        this.i.ahx.top = +v;
        this.i.ahx = this.i.ahx;
    }
    ensureUnitsTextMargin() {
        if (this.i.ahx) {
            return;
        }
        this.i.ahx = new Thickness(2);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get unitsTextStyle() {
        if (this.i.aa7 == null) {
            return null;
        }
        return this.i.aa7.fontString;
    }
    set unitsTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.aa7 = fi;
    }
    get titleTextMarginBottom() {
        return this.i.ahw ? this.i.ahw.bottom : NaN;
    }
    set titleTextMarginBottom(v) {
        this.ensureTitleTextMargin();
        this.i.ahw.bottom = +v;
        this.i.ahw = this.i.ahw;
    }
    get titleTextMarginLeft() {
        return this.i.ahw ? this.i.ahw.left : NaN;
    }
    set titleTextMarginLeft(v) {
        this.ensureTitleTextMargin();
        this.i.ahw.left = +v;
        this.i.ahw = this.i.ahw;
    }
    get titleTextMarginRight() {
        return this.i.ahw ? this.i.ahw.right : NaN;
    }
    set titleTextMarginRight(v) {
        this.ensureTitleTextMargin();
        this.i.ahw.right = +v;
        this.i.ahw = this.i.ahw;
    }
    get titleTextMarginTop() {
        return this.i.ahw ? this.i.ahw.top : NaN;
    }
    set titleTextMarginTop(v) {
        this.ensureTitleTextMargin();
        this.i.ahw.top = +v;
        this.i.ahw = this.i.ahw;
    }
    ensureTitleTextMargin() {
        if (this.i.ahw) {
            return;
        }
        this.i.ahw = new Thickness(2);
    }
    /**
     * Gets or sets the display text color.
    */
    get titleTextColor() {
        return brushToString(this.i.ahf);
    }
    set titleTextColor(v) {
        this.i.ahf = stringToBrush(v);
    }
    /**
     * Gets or Sets the style to use for the display text.
    */
    get titleTextStyle() {
        if (this.i.aa6 == null) {
            return null;
        }
        return this.i.aa6.fontString;
    }
    set titleTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.aa6 = fi;
    }
    /**
     * Gets or sets the mode for displaying labels before series values in the data legend, e.g. O: H: L: C: for financial series
    */
    get labelDisplayMode() {
        return this.i.z5;
    }
    set labelDisplayMode(v) {
        this.i.z5 = ensureEnum(DataLegendLabelMode_$type, v);
    }
    /**
     * Gets or sets the units text color.
    */
    get labelTextColor() {
        return brushToString(this.i.aha);
    }
    set labelTextColor(v) {
        this.i.aha = stringToBrush(v);
    }
    get labelTextMarginBottom() {
        return this.i.aht ? this.i.aht.bottom : NaN;
    }
    set labelTextMarginBottom(v) {
        this.ensureLabelTextMargin();
        this.i.aht.bottom = +v;
        this.i.aht = this.i.aht;
    }
    get labelTextMarginLeft() {
        return this.i.aht ? this.i.aht.left : NaN;
    }
    set labelTextMarginLeft(v) {
        this.ensureLabelTextMargin();
        this.i.aht.left = +v;
        this.i.aht = this.i.aht;
    }
    get labelTextMarginRight() {
        return this.i.aht ? this.i.aht.right : NaN;
    }
    set labelTextMarginRight(v) {
        this.ensureLabelTextMargin();
        this.i.aht.right = +v;
        this.i.aht = this.i.aht;
    }
    get labelTextMarginTop() {
        return this.i.aht ? this.i.aht.top : NaN;
    }
    set labelTextMarginTop(v) {
        this.ensureLabelTextMargin();
        this.i.aht.top = +v;
        this.i.aht = this.i.aht;
    }
    ensureLabelTextMargin() {
        if (this.i.aht) {
            return;
        }
        this.i.aht = new Thickness(2);
    }
    /**
     * Gets or Sets the style to use for the units text.
    */
    get labelTextStyle() {
        if (this.i.aa1 == null) {
            return null;
        }
        return this.i.aa1.fontString;
    }
    set labelTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.aa1 = fi;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.targetAxis && this.targetAxis.name && this.targetAxis.name == name) {
            return this.targetAxis;
        }
        if (this.valueFormatSpecifiers != null && arrayFindByName(this.valueFormatSpecifiers, name)) {
            return arrayFindByName(this.valueFormatSpecifiers, name);
        }
        if (this.headerFormatSpecifiers != null && arrayFindByName(this.headerFormatSpecifiers, name)) {
            return arrayFindByName(this.headerFormatSpecifiers, name);
        }
        return null;
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.targetAxis && this.targetAxis._styling) {
            this.targetAxis._styling(container, component, this);
        }
        this._inStyling = false;
    }
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    hideToolTips() {
        this.i.p4();
    }
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    hideToolTipsImmediate() {
        this.i.p5();
    }
}
